summaryrefslogtreecommitdiff
path: root/noncore/securityplugins
authorclem <clem>2004-08-05 22:55:35 (UTC)
committer clem <clem>2004-08-05 22:55:35 (UTC)
commit90ca457fbf420e31eed99c828a23e451bf8dc30c (patch) (side-by-side diff)
treebb538c99c6157a3e431818594fea92584783fc90 /noncore/securityplugins
parent75286b93291026578a6352797c830787a9401055 (diff)
downloadopie-90ca457fbf420e31eed99c828a23e451bf8dc30c.zip
opie-90ca457fbf420e31eed99c828a23e451bf8dc30c.tar.gz
opie-90ca457fbf420e31eed99c828a23e451bf8dc30c.tar.bz2
Don't bother with killing bluetooth anymore, since our
/etc/suspend-scripts/S50bluetooth new script does that just when we need it. Also, don't forget to shut down Bluetooth when we started it ourselves and when the authentication is finished (skipped or successfull). Finally, there's more info in the debug output now.
Diffstat (limited to 'noncore/securityplugins') (more/less context) (ignore whitespace changes)
-rw-r--r--noncore/securityplugins/blueping/bluepingplugin.cpp86
-rw-r--r--noncore/securityplugins/blueping/bluepingplugin.h7
2 files changed, 58 insertions, 35 deletions
diff --git a/noncore/securityplugins/blueping/bluepingplugin.h b/noncore/securityplugins/blueping/bluepingplugin.h
index b8d6734..56ff22d 100644
--- a/noncore/securityplugins/blueping/bluepingplugin.h
+++ b/noncore/securityplugins/blueping/bluepingplugin.h
@@ -75,7 +75,8 @@ class BluepingPlugin : public QObject, public Opie::Security::MultiauthPluginObj
private:
- Opie::Core::OProcess *m_ping;
+ void killBluetoothIfNecessary();
+ Opie::Core::OProcess * m_ping;
+ Config * m_config;
BluepingConfigWidget * m_bluepingW;
- bool bluetoothAlreadyRestarted;
+ bool bluetoothWasOff;
QString macToPing;
-
};
diff --git a/noncore/securityplugins/blueping/bluepingplugin.cpp b/noncore/securityplugins/blueping/bluepingplugin.cpp
index f5d9ad6..1c514e5 100644
--- a/noncore/securityplugins/blueping/bluepingplugin.cpp
+++ b/noncore/securityplugins/blueping/bluepingplugin.cpp
@@ -19,11 +19,13 @@ using Opie::Security::MultiauthConfigWidget;
/// standard c'tor
-BluepingPlugin::BluepingPlugin() : MultiauthPluginObject(), m_ping(0), m_bluepingW(0) {
- bluetoothAlreadyRestarted = false;
+BluepingPlugin::BluepingPlugin() : MultiauthPluginObject(), m_ping(0), m_bluepingW(0), bluetoothWasOff(false) {
}
-/// cleans m_ping if we need to
+/// cleans m_ping and m_bluepingW if we need to
BluepingPlugin::~BluepingPlugin() {
- delete m_ping;
+ odebug << "closing Blueping plugin..." << oendl;
+ if (m_ping != 0)
+ delete m_ping;
if (m_bluepingW != 0)
delete m_bluepingW;
+ killBluetoothIfNecessary();
}
@@ -41,2 +43,3 @@ MultiauthConfigWidget * BluepingPlugin::configWidget(QWidget * parent) {
}
+
QString BluepingPlugin::pixmapNameWidget() const {
@@ -44,2 +47,3 @@ QString BluepingPlugin::pixmapNameWidget() const {
}
+
QString BluepingPlugin::pixmapNameConfig() const {
@@ -48,2 +52,16 @@ QString BluepingPlugin::pixmapNameConfig() const {
+/// If Bluetooth was off before the plugin ran, we switch it off again
+void BluepingPlugin::killBluetoothIfNecessary() {
+ if (bluetoothWasOff) {
+ OProcess killB;
+ killB << "killall" << "hciattach";
+ odebug << "killing Bluetooth... (since it was up only for Blueping)" << oendl;
+ if ( !killB.start(OProcess::Block) ) {
+ oerr << "could not kill bluetooth" << oendl;
+ }
+ } else {
+ odebug << "keeping Bluetooth on" << oendl;
+ }
+}
+
/// Emit the MultiauthPluginObject::Success emitCode
@@ -83,14 +101,14 @@ void BluepingPlugin::ping() {
/// Deals with m_ping result
- void BluepingPlugin::pingFinished(OProcess * ping) {
- if ( ping->normalExit() && (ping->exitStatus() == 0) )
- {
- odebug << "Successful Bluetooth ping!" << oendl;
- success();
- }
- else
- {
- odebug << "Failed Bluetooth ping..." << oendl;
- failure();
- }
+void BluepingPlugin::pingFinished(OProcess * ping) {
+ if ( ping->normalExit() && (ping->exitStatus() == 0) )
+ {
+ odebug << "Successful Bluetooth ping!" << oendl;
+ success();
}
+ else
+ {
+ odebug << "Failed Bluetooth ping... (normalExit: " << ping->normalExit() << ", exitStatus: " << ping->exitStatus() << ")" << oendl;
+ failure();
+ }
+}
@@ -138,13 +156,16 @@ int BluepingPlugin::authenticate() {
- // we can uncomment the following when testing
- //bluetoothAlreadyRestarted = true;
- if (!bluetoothAlreadyRestarted)
+
+
+ /* let's start Bluetooth if it's not running
+ */
+ OProcess checkB;
+ checkB << "pidof" << "hciattach";
+ odebug << "checking if Bluetooth is running..." << oendl;
+ // now we start bluetooth *only* if the previous command works, exits normally, and
+ // it returns a non-null exit code (which means hciattach is not running)
+ if ( checkB.start(OProcess::Block) && checkB.normalExit() && (checkB.exitStatus() != 0) )
{
- // we have just started or resumed the device, so Bluetooth has to be (re)started
- OProcess killB;
- killB << "killall" << "hciattach";
- odebug << "killing Bluetooth..." << oendl;
- if ( !killB.start(OProcess::Block) ) {
- oerr << "could not kill bluetooth" << oendl;
- }
+ // remember to switch off Bluetooth once we're finished...
+ bluetoothWasOff = true;
+ odebug << "Bluetooth is not running, we must start it now" << oendl;
@@ -166,3 +187,3 @@ int BluepingPlugin::authenticate() {
if ( !startB.start(OProcess::Block) ) {
- oerr << "could not (re)start bluetooth" << oendl;
+ oerr << "could not start Bluetooth" << oendl;
return MultiauthPluginObject::Skip;
@@ -171,6 +192,5 @@ int BluepingPlugin::authenticate() {
{
- if ( startB.normalExit() && (startB.exitStatus() == 0) )
+ if ( (startB.normalExit()) && (startB.exitStatus() == 0) )
{
- odebug << "hciattach exited normally."<< oendl;
- bluetoothAlreadyRestarted = true;
+ odebug << "hciattach exited normally, Bluetooth is probably on now, let's wait 500 ms and ping" << oendl;
// 500 ms timer, so l2ping won't try to find a route before bluetooth has \em really started
@@ -180,4 +200,5 @@ int BluepingPlugin::authenticate() {
{
- owarn << "hciattach exited anormally (error code: " << startB.exitStatus() << ")" << oendl;
- } // end if startBluetooth exit status == 0
+ owarn << "hciattach exited anormally (normalExit: " << startB.normalExit() << ", exit status: " << startB.exitStatus() << ")" << oendl;
+ return MultiauthPluginObject::Skip;
+ } // end if startB exited normaly
} // end if startBluetooth started
@@ -187,4 +208,5 @@ int BluepingPlugin::authenticate() {
// we don't need to wait, since bluetooth has been started long enough ago
+ odebug << "Bluetooth is already running, we can try to ping now" << oendl;
ping();
- } // end if bluetooth not restarted
+ } // end if Bluetooth was off